summaryrefslogtreecommitdiff
path: root/src/target/arm11.c
diff options
context:
space:
mode:
authorzwelch <zwelch@b42882b7-edfa-0310-969c-e2dbd0fdcd60>2009-06-18 07:07:59 +0000
committerzwelch <zwelch@b42882b7-edfa-0310-969c-e2dbd0fdcd60>2009-06-18 07:07:59 +0000
commitf876d5e9c769a288faa7fd14b7bf373363542aab (patch)
tree86ad76530f7d44c69471813c4c727f107b018eb5 /src/target/arm11.c
parentc18947b947064e7eceed8047c42d4c8dfd8ae964 (diff)
downloadopenocd_libswd-f876d5e9c769a288faa7fd14b7bf373363542aab.tar.gz
openocd_libswd-f876d5e9c769a288faa7fd14b7bf373363542aab.tar.bz2
openocd_libswd-f876d5e9c769a288faa7fd14b7bf373363542aab.tar.xz
openocd_libswd-f876d5e9c769a288faa7fd14b7bf373363542aab.zip
Transform 'u16' to 'uint16_t'
- Replace '\([^_]\)u16' with '\1uint16_t'. - Replace '^u16' with 'uint16_t'. git-svn-id: svn://svn.berlios.de/openocd/trunk@2277 b42882b7-edfa-0310-969c-e2dbd0fdcd60
Diffstat (limited to 'src/target/arm11.c')
-rw-r--r--src/target/arm11.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/target/arm11.c b/src/target/arm11.c
index 7e8c4c67..380f2cea 100644
--- a/src/target/arm11.c
+++ b/src/target/arm11.c
@@ -1092,7 +1092,7 @@ int arm11_get_gdb_reg_list(struct target_s *target, struct reg_s **reg_list[], i
*/
int arm11_read_memory(struct target_s *target, u32 address, u32 size, u32 count, uint8_t *buffer)
{
/** \todo TODO: check if buffer cast to u32* and u16* might cause alignment problems */
FNC_INFO;
@@ -1148,8 +1148,8 @@ int arm11_read_memory(struct target_s *target, u32 address, u32 size, u32 count,
/* MCR p14,0,R1,c0,c5,0 */
arm11_run_instr_data_from_core(arm11, 0xEE001E15, &res, 1);
- u16 svalue = res;
- memcpy(buffer + count * sizeof(u16), &svalue, sizeof(u16));
+ uint16_t svalue = res;
+ memcpy(buffer + count * sizeof(uint16_t), &svalue, sizeof(uint16_t));
}
break;
@@ -1218,8 +1218,8 @@ int arm11_write_memory(struct target_s *target, u32 address, u32 size, u32 count
for (size_t i = 0; i < count; i++)
{
- u16 value;
- memcpy(&value, buffer + count * sizeof(u16), sizeof(u16));
+ uint16_t value;
+ memcpy(&value, buffer + count * sizeof(uint16_t), sizeof(uint16_t));
/* MRC p14,0,r1,c0,c5,0 */
arm11_run_instr_data_to_core1(arm11, 0xee101e15, value);
@@ -1092,7 +1092,7 @@ int arm11_get_gdb_reg_list(struct target_s *target, struct reg_s **reg_list[], i
int arm11_read_memory(struct target_s *target, u32 address, u32 size, u32 count, uint8_t *buffer)
{
- /** \todo TODO: check if buffer cast to u32* and u16* might cause alignment problems */
+ /** \todo TODO: check if buffer cast to u32* and uint16_t* might cause alignment problems */
FNC_INFO;